# Core

The [core](#core) of **GALACTIC** is organized into several layers,
allowing the underlying theories to be addressed independently of each other
while also making package maintenance easier:

## Generic algebraic structures

::::{grid} 1 2 2 2
:gutter: 1 1 1 2

:::{grid-item-card} Kernel
:link: https://galactic.univ-lr.fr/docs/core/kernel/latest/
:link-alt: Kernel
![Sets](/_images/architecture/set.svg)
![Relations](/_images/architecture/relation.svg)
![Posets](/_images/architecture/poset.svg)
![Lattices](/_images/architecture/lattice.svg)

A *python* package to manage set notions, relational notions, partially ordered sets,
and lattices, called the *kernel*.
+++
[Learn more »](https://galactic.univ-lr.fr/docs/core/kernel/latest/)
:::

:::{grid-item-card} Closures
:link: https://galactic.univ-lr.fr/docs/core/closure/latest/
:link-alt: Closures
![Closure operators](/_images/architecture/closure.svg)
![Closed sets](/_images/architecture/closed.svg)
![Galois connections](/_images/architecture/thegalactic.svg)

A *python* package to manage closure operators, closed sets and Galois connections.
+++
[Learn more »](https://galactic.univ-lr.fr/docs/core/closure/latest/)
:::
::::

:::{seealso}
* [Relational theory](/theory/relations)
* [Poset theory](/theory/posets)
* [Lattice theory](/theory/lattices)
* [Closure theory](/theory/operators)
:::

## Concept lattices

::::{grid} 1 2 2 2
:gutter: 1 1 1 2

:::{grid-item-card} Concepts
:link: https://galactic.univ-lr.fr/docs/core/concept/latest/
:link-alt: Concepts
![Formal concepts](/_images/architecture/concept.svg)

A *python* package to manage classical **F**ormal **C**oncept **A**nalysis 
by producing concept lattices.
+++
[Learn more »](https://galactic.univ-lr.fr/docs/core/concept/latest/)
:::
::::

## Description lattices

::::{grid} 1 2 2 2
:gutter: 1 1 1 2

:::{grid-item-card} Convex
:link: https://galactic.univ-lr.fr/docs/core/convex/latest/
:link-alt: Convex
![Convex](/_images/architecture/pattern.svg)

A *python* package to manage **F**ormal **C**oncept **A**nalysis described by the
boundaries of generalized convex hulls. There exist various extensions added to this part.
+++
[Learn more »](https://galactic.univ-lr.fr/docs/core/convex/latest/)
:::

:::{grid-item-card} Strategies
![Strategies](/_images/architecture/strategy.svg)

A *python* package to create description lattices using strategies. 
There exist various extensions added to this part.
+++
🚧 Coming soon… 🚧
:::

::::

~~~{image} /_images/architecture/core.svg
:alt: The Core of GALACTIC
:align: center
:name: core
~~~
