"""The configuration module for sphinx."""

import json
import os

# Get metadata
metadata = json.load(os.popen("hatch project metadata"))
project = metadata["name"]
author = ",".join(author["name"] for author in metadata["authors"])
version = metadata["version"]
project_copyright = f"2018-%Y, {author}"

# -- General configuration ------------------------------------------------

extensions = [
    "sphinx.ext.graphviz",
    "myst_parser",
    "sphinx_design",
    "sphinxcontrib.bibtex",
]

myst_enable_extensions = [
    "colon_fence",
    "attrs_inline",
    "attrs_block",
    "deflist",
    "tasklist",
    "fieldlist",
    "dollarmath",
    "amsmath",
]

graphviz_output_format = "svg"

suppress_warnings = [
#    "myst.xref_missing",
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# The master document.
master_doc = "index"

# The language for content by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = "en"

# The name of the (syntax highlighting) style to use.
pygments_style = "sphinx"

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = True

# -- Options for HTML output ----------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
html_theme = "pydata_sphinx_theme"

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
html_theme_options = {
    "navigation_depth": 3,
    "logo": {
        "image_dark": "_images/logos/thegalactic-dark.svg",
    },
    "article_header_start": ["conditional-breadcrumbs"],
    "footer_start": ["copyright"],
    "footer_center": ["sphinx-version"],
    "navbar_end": ["theme-switcher", "additional-links"],
}

html_sidebars = {
    "intro": [],
    "packages": [],
}

html_show_sourcelink = False
html_favicon = "thegalactic.ico"
html_logo = "_images/logos/thegalactic.svg"
html_title = ""

# Bibtex
bibtex_bibfiles = [
    "refs.bib",
    "theory/refs.bib",
]
