---
sd_hide_title: true
myst:
  html_meta:
    "description lang=en": |
      Top-level documentation for GALACTIC, with links to the rest
      of the site.
html_theme.sidebar_secondary.remove: true
---

# 🔎 Overview

::::{grid}
:reverse:
:gutter: 3 4 4 4
:margin: 1 2 1 2

:::{grid-item}
:columns: 12 4 4 4

```{image} /_images/logos/thegalactic.svg
:width: 200px
:class: sd-m-auto only-light
:name: landing-page-logo
```
```{image} /_images/logos/thegalactic-dark.svg
:width: 200px
:class: sd-m-auto only-dark
:name: landing-page-logo-dark
```

:::

:::{grid-item}
:columns: 12 8 8 8
:child-align: justify
:class: sd-fs-5

```{rubric} GALACTIC
```

**GALACTIC** is a research project for studying
[Formal Concept Analysis](https://en.wikipedia.org/wiki/Formal_concept_analysis)
designed with an algebraic core around which revolve, on the one hand,
extensions detected at runtime and, on the other hand, applications themselves
architected with the same extensibility mechanism. The whole is complemented by
theoretical elements and teaching resources that allow one to grasp, step by step,
the concepts intrinsic to its comprehension.
````{div} sd-d-flex-row
```{button-ref} intro
:ref-type: doc
:color: primary
:class: sd-rounded-pill sd-mr-3

Get Started
```
````
:::
::::

**GALACTIC** stands for
**GA**lois
**LA**ttices,
**C**oncept
**T**heory,
**I**mplicational systems and
**C**losures.

---

::::{grid} 1 2 2 3
:gutter: 1 1 1 2

:::{grid-item-card} 🏢 Architecture
:link: architecture/index.html
:link-alt: Architecture

The **GALACTIC** project is built around a core composed of a central kernel extended
by various algebras. Some components can be transparently extended using python packages.
Around this central core revolve applications in terminal mode or with
a graphical interface, most of which are also extensible.
+++
[Learn more »](architecture/index)
:::

:::{grid-item-card} 📖 Theoretical foundations
:link: theory/index.html
:link-alt: Theoretical foundations

The **GALACTIC** project finds its theoretical foundations in several branches
of discrete mathematics, in particular the theory of partially ordered sets,
lattices, closure operators, concept formal analysis and convex geometries.

+++
[Learn more »](theory/index)
:::

:::{grid-item-card} 🏫 Teaching Resources
:link: teaching/index.html
:link-alt: Teaching Resources

We have supported this software project by developing teaching resources adapted to
the learning level of undergraduate, masters and PhD students.

+++
[Learn more »](teaching/index)
:::

::::

---

```{rubric} Additional resources
```

[Publications](publications)
: A non-exhaustive list of publications on the **GALACTIC** project.

[Mailing list](https://ml.univ-lr.fr/sympa/info/galactic)
: A mailing list dedicated to the **GALACTIC** project.

[Guides](guides)
: A list of guides for the **GALACTIC** project.

[Reports](reports)
: A list of student reports on the **GALACTIC** project.

```{rubric} Acknowledgements
```

The **GALACTIC** project could not have advanced without the involvement of numerous
[contributors](contributors) who aided in its development.

```{toctree}
:hidden:
intro
🏢 Architecture <architecture/index>
📖 Theory <theory/index>
🏫 Teaching <teaching/index>
📦 Packages <packages>
```
