:::{index} single: Operators
:name: Operators
:::


# Operators

::::{grid}
:reverse:
:gutter: 3 4 4 4
:margin: 1 2 1 2

:::{grid-item-card}
:link: https://galactic.univ-lr.fr/docs/core/closure/latest/
:link-alt: Closure
:columns: 12 4 4 4
```{image} /_images/logos/Python-galactic.svg
:width: 200px
:class: sd-m-auto
```
+++
**GALACTIC** core closure
:::

:::{grid-item}
:columns: 12 8 8 8
:child-align: justify
:class: sd-fs-5

A closure operator is a function that maps an element of a partially ordered set (poset)
to another element in the same set, ensuring that the result is **closed** in a
specific sense.  

:::
::::

:::{index} pair: Operators; Set theoretic operators
:name: Operators; Set theoretic operators
:::

## Set theoretic operators

:::{rubric} Definition
:::

For a set $X$, we denote $2^X$ as the set of subsets of $X$.
We recall that a set-theoretic operator $\phi$ on $X$ is a function from $2^X$ to $2^X$.

:::{rubric} Properties
:::

:::{index} triple: Operators; Set theoretic operators; Extensibility
:name: Operators; Set theoretic operators; Extensibility
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Extensibility
The operator $\phi$ is said to be extensive if:

$$
\forall A \subseteq X, A \subseteq \phi(A)
$$
:::
::::

:::{index} triple: Operators; Set theoretic operators; Contractivity
:name: Operators; Set theoretic operators; Contractivity
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Contractivity
The operator $\phi$ is said to be contractive if:

$$
\forall A \subseteq X, A \supseteq \phi(A)
$$
:::
::::

:::{index} triple: Operators; Set theoretic operators; Isotonicity
:name: Operators; Set theoretic operators; Isotonicity
:::
:::{index} triple: Operators; Set theoretic operators; Monotonicity
:name: Operators; Set theoretic operators; Monotonicity
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Isotonicity
The operator $\phi$ is said to be isotone (or monotone) if:

$$
\forall A, B \subseteq X, A\subseteq B \implies \phi(A) \subseteq \phi(B)
$$
:::
::::

:::{index} triple: Operators; Set theoretic operators; Antitonicity
:name: Operators; Set theoretic operators; Antitonicity
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Antitonicity
The operator $\phi$ is said to be antitone if:

$$
\forall A, B \subseteq X, A\subseteq B \implies \phi(A) \supseteq \phi(B)
$$
:::
::::

:::{index} triple: Operators; Set theoretic operators; Idempotence
:name: Operators; Set theoretic operators; Idempotence
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Idempotence
The operator $\phi$ is said to be idempotent if:

$$
\forall A \subseteq X, \phi\circ\phi(A) = \phi(A)
$$
:::
::::

:::{index} triple: Operators; Set theoretic operators; Normalization
:name: Operators; Set theoretic operators; Normalization
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Normalization
The operator $\phi$ is said to be normalized if:

$$
\phi(\emptyset)=\emptyset
$$
:::
::::

:::{index} triple: Operators; Set theoretic operators; Anti-exchange
:name: Operators; Set theoretic operators; Anti-exchange
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Anti-exchange
The operator $\phi$ is said to have the anti-exchange property if:

$$
\forall A\subseteq X, \forall p \neq q \in  X \setminus \phi(A), p \in \phi(\{q\}\cup A) \implies q \notin \phi(\{p\} \cup A)
$$
:::
::::

:::{index} triple: Operators; Set theoretic operators; Atomicity
:name: Operators; Set theoretic operators; Atomicity
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Atomicity
The operator $\phi$ is said to be atomic if it is normalized and:

$$
\forall p\in X, \phi(\{p\}) = \{p\}
$$
:::
::::

:::{index} triple: Operators; Set theoretic operators; Algebraic
:name: Operators; Set theoretic operators; Algebraic
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Algebraic
The operator $\phi$ is said to be algebraic if:

$$
\forall A, B\subseteq X, \phi(A)=\bigcup\{\phi(B)\;|\;B\subseteq A \mbox{ finite}\}
$$
:::
::::

:::{index} pair: Operators; Closure operators
:name: Operators; Closure operators
:::
:::{index} pair: Operators; Closed set
:name: Operators; Closed set
:::

## Closure operators

:::{rubric} Definition
:::

Let $X$ be a ground set. An operator $\phi$ is called a **closure operator** if it
satisfies the following properties:

[Extensitivity](#operators-set-theoretic-operators-extensibility)
: The operator is extensive.

[Idempotence](#operators-set-theoretic-operators-idempotence)
: The operator is idempotent.

[Isotonicity](#operators-set-theoretic-operators-isotonicity)
: The operator is isotone.

Let $A\subset X$, $\phi(A)$ is called a closed set.

:::{index} pair: Operators; Moore family
:name: Operators; Moore family
:::
:::{index} pair: Operators; Closure system
:name: Operators; Closure system
:::

## Moore Families

The set of images by $\phi$ of all subsets of $X$ forms a closure system or Moore family.
It is a collection of subsets that is closed under arbitrary intersections.

:::{index} pair: Operators; (Antitone) Galois connection
:name: Operators; Antitone Galois connection
:::
:::{index} pair: Operators; Galois connection
:name: Operators; Galois connection
:::

## Antitone Galois connection

An (antitone) Galois connection between the parts of $X$ and the parts of $Y$ is a couple
of antitone functions $\left\langle\alpha: 2^X\to 2^Y, \beta: 2^Y\to 2^X \right\rangle$ such that:

$$
\forall A \subseteq X,B\subseteq Y, B \subseteq \alpha(A) \iff A \subseteq \beta(B)
$$

The compositions of $\alpha$ and $\beta$ form closure operators on $X$ and $Y$
($\beta\circ\alpha$ is a closure operator on $X$ and $\alpha\circ\beta=$ is a closure 
operator on $Y$).