:::{index} single: Posets
:name: Posets
:::

# Posets

::::{grid}
:reverse:
:gutter: 3 4 4 4
:margin: 1 2 1 2

:::{grid-item-card}
:link: https://galactic.univ-lr.fr/docs/core/kernel/latest/
:link-alt: Kernel
:columns: 12 4 4 4
```{image} /_images/logos/Python-galactic.svg
:width: 200px
:class: sd-m-auto
```
+++
**GALACTIC** core kernel
:::

:::{grid-item}
:columns: 12 8 8 8
:child-align: justify
:class: sd-fs-5

A partially ordered set {cite:p}`pinter2014book`, often abbreviated as **poset**,
is a mathematical structure that captures the idea of ordering elements in a way
that some pairs of elements can be compared, but not necessarily all.
Think of it like organizing items where some can be clearly ranked,
but others might not be directly comparable.

:::
::::

:::{index} pair: Posets; Partial orders
:name: Partial orders
:::

## Partial orders

A partial order is a binary relation that captures the intuitive notion of one element
being ***less than or equal to*** another element in a set. It is defined mathematically
using specific properties.

:::{rubric} Definition
:::

Let $P$ be a set and $\leq$ be a
[endo-relation](relations.md#relations-endo-relations)
on $P$.
The relation $\leq$ is a **partial order** on $P$ if it satisfies the following properties:

[Reflexivity](relations.md#relations-endo-relations-reflexivity)
: Every element is related to itself.

[Antisymmetry](relations.md#relations-endo-relations-antisymmetry)
: There are no distinct elements that relate to each other in both directions unless
  they are the same element.

[Transitivity](relations.md#relations-endo-relations-transitivity)
: The relation is preserved across connected elements.

:::{rubric} Properties
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Comparability
In a partial order, not all elements need to be comparable.
There may exist elements $a$ and $b$ such that neither $a \leq b$ nor $b \leq a$.
:::

:::{grid-item-card}  Total Order
If every pair of elements in the set is comparable, the partial order is called a
**total order** or linear order.
:::
::::

A set equipped with a partial order is called a **partially ordered set** (poset).

:::{index} pair: Posets; Covering relations
:name: Covering relations
:::

## Covering relations

In the context of partially ordered sets (posets), the covering relation is an
[endo-relation](relations.md#relations-endo-relations) that describes a 
direct or immediate predecessorship between elements.

:::{rubric} Definition
:::

Let $\left\langle P, \leq\right\rangle$ be a poset, where $P$ is a set and $\leq$ is a
partial order on $P$.

An element $a$ is said to **be covered** by another element $b$ if:

$$
a \prec b \iff a < b \text{ and } \nexists c \in P \text{ such that } a < c < b.
$$

:::{rubric} Properties
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Immediate predecessor
If $a\prec b$, then $a$ is an immediate predecessor of $b$, meaning there are no
intermediate elements between $a$ and $b$ in the partial order.
:::

:::{grid-item-card}  Hasse Diagram
In a Hasse diagram, which visually represents a poset, an edge directly connects $a$ to
$b$ if and only if $a\prec b$.
:::

:::{grid-item-card}  Minimal and maximal elements
The covering relation helps identify minimal and maximal elements in a poset, as these
elements do not have any elements covering them or being covered by them, respectively.
:::
