:::{index} single: Relations
:name: Relations
:::

# Relations

::::{grid}
:reverse:
:gutter: 3 4 4 4
:margin: 1 2 1 2

:::{grid-item-card}
:link: https://galactic.univ-lr.fr/docs/core/kernel/latest/
:link-alt: Kernel
:columns: 12 4 4 4
```{image} /_images/logos/Python-galactic.svg
:width: 200px
:class: sd-m-auto
```
+++
**GALACTIC** core kernel
:::

:::{grid-item}
:columns: 12 8 8 8
:child-align: justify
:class: sd-fs-5

A relation {cite:p}`pinter2014book` is a way to describe how elements from one or more sets are connected or
associated with each other. It's a fundamental idea in mathematics and other fields that
helps us understand and organize information based on these connections. 

:::
::::

:::{index} pair: Relations; Cartesian product
:name: Relations; Cartesian product
:::

## Cartesian product

:::{rubric} Definition
:::

Let {math}`A` and {math}`B` be two sets. The Cartesian product of {math}`A` and {math}`B`,
denoted {math}`A \times B`, is the set of all ordered pairs {math}`(a, b)` where {math}`a`
is an element of {math}`A` and {math}`b` is an element of {math}`B`. Formally,

```{math}
A \times B = \{(a, b) \mid a \in A \text{ and } b \in B\}
```

:::{rubric} Properties
:::

:::{index} triple: Relations; Cartesian product; Commutativity
:name: Relations; Cartesian product; Commutativity
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Non-commutative
In general, {math}`A \times B \neq B \times A`. The pairs {math}`(a, b)` and
{math}`(b, a)` are distinct unless {math}`a = b`.
:::
::::

:::{index} triple: Relations; Cartesian product; Cardinality
:name: Relations; Cartesian product; Cardinality
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Cardinality

If {math}`A` and {math}`B` are finite sets, then the cardinality of {math}`A \times B` is
the product of the cardinalities of {math}`A` and {math}`B`.
If {math}`|A| = m` and {math}`|B| = n`, then {math}`|A \times B| = m \times n`.
:::
::::

:::{index} triple: Relations; Cartesian product; Associativity
:name: Relations; Cartesian product; Associativity
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Associativity
The Cartesian product is associative in the sense that {math}`(A \times B) \times C` is
isomorphic to {math}`A \times (B \times C)`.
:::

::::

:::{index} pair: Relations; Binary relations
:name: Relations; Binary relations
:::

## Binary relations

:::{rubric} Definition
:::

Let {math}`A` and {math}`B` be two sets. A binary relation {math}`R` from {math}`A` to
{math}`B` is a subset of the Cartesian product {math}`A \times B`.
In other words, {math}`R` is a set of ordered pairs {math}`(a, b)` where {math}`a \in A`
and {math}`b \in B`. Formally,

```{math}
R \subseteq A \times B
```

:::{index} pair: Relations; n-ary relations
:name: Relations; n-ary relations
:::

## {math}`n`-ary relations

:::{rubric} Definition
:::

Let {math}`A_1, A_2, \ldots, A_n` be {math}`n` sets. An n-ary relation {math}`R` over
these sets is a subset of the Cartesian product
{math}`A_1 \times A_2 \times \cdots \times A_n`.
In other words, {math}`R` is a set of ordered n-tuples {math}`(a_1, a_2, \ldots, a_n)`
where {math}`a_i \in A_i` for {math}`i = 1, 2, \ldots, n`. Formally,

```{math}
R \subseteq A_1 \times A_2 \times \cdots \times A_n
```

:::{index} pair: Relations; Endo relations
:name: Relations; Endo relations
:::

## Endo relations

:::{rubric} Definition
:::

An endo-relation is a binary relation on a single set {math}`A`.
It is a subset of the Cartesian product {math}`A \times A`, meaning it relates elements
within the same set. Formally, an endo-relation {math}`R` on {math}`A` is defined as:

```{math}
R \subseteq A \times A
```

This means {math}`R` consists of ordered pairs {math}`(a, b)` where both
{math}`a` and {math}`b` are elements of {math}`A`.

:::{rubric} Properties
:::

:::{index} triple: Relations; Endo relations; Reflexivity
:name: Relations;  Endo relations; Reflexivity
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Reflexivity 
A relation {math}`R` is reflexive if every element is related to itself. Formally:

```{math}
\forall a \in A, (a, a) \in R
```
:::
::::

:::{index} triple: Relations; Endo relations; Irreflexivity
:name: Relations; Endo relations; Irreflexivity
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Irreflexivity
A relation {math}`R` is irreflexive if no element is related to itself. Formally:

```{math}
\forall a \in A, (a, a) \notin R
```
:::
::::

:::{index} triple: Relations; Endo relations; Symmetry
:name: Relations; Endo relations; Symmetry
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Symmetry
A relation {math}`R` is symmetric if whenever {math}`a` is related to {math}`b`,
then {math}`b` is related to {math}`a`. Formally:

```{math}
\forall a, b \in A, (a, b) \in R \implies (b, a) \in R
```
:::
::::

:::{index} triple: Relations; Endo relations; Antisymmetry
:name: Relations; Endo relations; Antisymmetry
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Antisymmetry
A relation {math}`R` is antisymmetric if whenever {math}`a` is related to {math}`b`
and {math}`b` is related to {math}`a`, then {math}`a` must be equal to {math}`b`.
Formally:

```{math}
\forall a, b \in A, (a, b) \in R \text{ and } (b, a) \in R \implies a = b
```
:::
::::

:::{index} triple: Relations; Endo relations; Asymmetry
:name: Relations; Endo relations; Asymmetry
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Asymmetry
A relation {math}`R` is asymmetric if whenever {math}`a` is related to {math}`b`,
then {math}`b` cannot be related to {math}`a`. Formally:

```{math}
\forall a, b \in A, (a, b) \in R \implies (b, a) \notin R
```
:::
::::

:::{index} triple: Relations; Endo relations; Transitivity
:name: Relations; Endo relations; Transitivity
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Transitivity
A relation {math}`R` is transitive if whenever {math}`a` is related to {math}`b`
and {math}`b` is related to {math}`c`, then {math}`a` is related to {math}`c`. Formally:

```{math}
\forall a, b, c \in A, (a, b) \in R \text{ and } (b, c) \in R \implies (a, c) \in R
```
:::
::::

:::{index} triple: Relations; Endo relations; Connected
:name: Relations; Endo relations; Connected
:::
:::{index} triple: Relations; Endo relations; Total
:name: Relations; Endo relations; Total
:::

::::{grid} 1
:gutter: 1

:::{grid-item-card}  Connected (or Total)
A relation {math}`R` is connected if for every pair of distinct elements {math}`a` and
{math}`b`, either {math}`a` is related to {math}`b` or {math}`b` is related to {math}`a`. 
Formally:

```{math}
\forall a, b \in A, a \neq b \implies (a, b) \in R \text{ or } (b, a) \in R
```
:::
::::