# Data

The data can come from files or any other source that adheres to the protocol defined in
the core of the population helper package.

For data stored in files, a plugin mechanism allows the transformation of their content
into dedicated Python objects for exploitation. Each extension registers with the 
population factory to enable the class to be used when creating the population based on
the file extension.

## Helpers and core

::::{grid} 1 2 2 2
:gutter: 1 1 1 2

:::{grid-item-card} Population helper
:link: https://galactic.univ-lr.fr/docs/helpers/population/latest/
:link-alt: Population helper
![Population helper](/_images/helpers/population.svg)

A *python* package defining population classes.
+++
[Learn more »](https://galactic.univ-lr.fr/docs/helpers/population/latest/)
:::

:::{grid-item-card} Core
:link: https://galactic.univ-lr.fr/docs/io/data/core/latest/
:link-alt: Core
![Core](/_images/io/data/core.svg)

A *python* package defining protocols for reading and writing data to files,
along with a factory for registering extensions.
+++
[Learn more »](https://galactic.univ-lr.fr/docs/io/data/core/latest/)
:::
::::

## Binary data

::::{grid} 1 2 2 2
:gutter: 1 1 1 2

:::{grid-item-card} Burmeister
:link: https://galactic.univ-lr.fr/docs/io/data/burmeister/latest/
:link-alt: Burmeister

A *python* package that allows reading files in the **Burmeister**
format, with the `.cxt` extension.
+++
[Learn more »](https://galactic.univ-lr.fr/docs/io/data/burmeister/latest/)
:::

:::{grid-item-card} Frequent Itemset Mining Implementations
:link: https://galactic.univ-lr.fr/docs/io/data/fimi/latest/
:link-alt: Frequent Itemset Mining Implementations

A *python* package that allows reading files in the **FIMI**
format, with the `.fimi` extension.
+++
[Learn more »](https://galactic.univ-lr.fr/docs/io/data/fimi/latest/)
:::

:::{grid-item-card} Text
:link: https://galactic.univ-lr.fr/docs/io/data/text/latest/
:link-alt: Text

A *python* package that allows reading files in the **text**
format, with the `.txt` extension.
+++
[Learn more »](https://galactic.univ-lr.fr/docs/io/data/text/latest/)
:::

:::{grid-item-card} Standard Lattice Format
:link: https://galactic.univ-lr.fr/docs/io/data/slf/latest/
:link-alt: Standard Lattice Format

A *python* package that allows reading files in the **S**tandard **L**attice **F**ormat,
with the `.slf` extension.
+++
[Learn more »](https://galactic.univ-lr.fr/docs/io/data/slf/latest/)
:::

::::

## Heterogeneous data

::::{grid} 1 2 2 2
:gutter: 1 1 1 2

:::{grid-item-card} Comma-Separated Values
:link: https://galactic.univ-lr.fr/docs/io/data/csv/latest/
:link-alt: Comma-Separated Values

A *python* package that allows reading files in the **CSV**
format, with the `.csv` extension.
+++
[Learn more »](https://galactic.univ-lr.fr/docs/io/data/csv/latest/)
:::

:::{grid-item-card} INI
:link: https://galactic.univ-lr.fr/docs/io/data/ini/latest/
:link-alt: INI

A *python* package that allows reading files in the **INI**
format, with the `.ini` extension.
+++
[Learn more »](https://galactic.univ-lr.fr/docs/io/data/ini/latest/)
:::

::::

## Complex data

::::{grid} 1 2 2 2
:gutter: 1 1 1 2

:::{grid-item-card} JavaScript Object Notation
:link: https://galactic.univ-lr.fr/docs/io/data/json/latest/
:link-alt: JavaScript Object Notation

A *python* package that allows reading files in the
**J**ava**S**cript **O**bject **N**otation
format, with the `.json` extension.
+++
[Learn more »](https://galactic.univ-lr.fr/docs/io/data/json/latest/)
:::

:::{grid-item-card} Tom's Obvious, Minimal Language
:link: https://galactic.univ-lr.fr/docs/io/data/toml/latest/
:link-alt: Tom's Obvious, Minimal Language 

A *python* package that allows reading files in the
**TOML**
format, with the `.toml` extension.
+++
[Learn more »](https://galactic.univ-lr.fr/docs/io/data/toml/latest/)
:::

:::{grid-item-card} YAML Ain't Markup Language
:link: https://galactic.univ-lr.fr/docs/io/data/yaml/latest/
:link-alt: YAML Ain't Markup Language

A *python* package that allows reading files in the
**YAML**
format, with the `.yaml` and `.yml` extensions.
+++
[Learn more »](https://galactic.univ-lr.fr/docs/io/data/yaml/latest/)
:::

::::

